@@ -1,9 +1,11 @@
 import dataclasses
 from typing import Dict, Optional
 
+from pydantic import root_validator
 from pydantic.dataclasses import dataclass
 
 from metaphor.common.base_config import BaseConfig
+from metaphor.common.utils import must_set_exactly_one
 
 
 @dataclass
@@ -39,3 +41,8 @@ class TableauRunConfig(BaseConfig):
 
     # whether to disable Chart preview image
     disable_preview_image: bool = False
+
+    @root_validator
+    def have_access_token_or_user_password(cls, values):
+        must_set_exactly_one(values, ["access_token", "user_password"])
+        return values
